# openbabel-wheel

`openbabel-wheel` is an unofficial repository to distribute OpenBabel prebuilt wheels through Pypi.

The project is inspired by [rdkit-pypi](https://github.com/kuelumbus/rdkit-pypi) and powered by [cibuildwheel](https://github.com/pypa/cibuildwheel). 

The repository is still experimental.

`openbabel-wheel` distributed under the same [license](LICENSE) as OpenBabel.
For original OpenBabel repository, refer [openbabel/openbabel](https://github.com/openbabel/openbabel).
